# browser-date-formatter

Format dates real fancy-like in the browser. Good for search engines and humans.

This was originally implemented on [the npmjs.com website](https://github.com/npm/newww/blob/ec7ed58a3406c2ebd7a121218b99349432d8d575/assets/scripts/date-formatting.js), then proved useful enough to extract into a standalone module.

Weighs in at 4K, minified and gzipped.

## Installation

```sh
npm install browser-date-formatter --save
```

## Usage

Specify `date` and `format` data attributes on all HTML elements you want
formatted:

```html
<span data-date="Thu Apr 07 2016 17:00:00 GMT-0700 (PDT)" data-format="%Y-%m-%d">
  (any textContent you put here will be replaced with "2016-04-07")
</span>
```

The `date` data attribute should be a stringified representation of a [JavaScript Date
object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date),
e.g. `String(new Date())`

The `format` data attribute is optional. If omitted, a human-friendly relative date
string like "5 minutes ago" is displayed. If specified, the format is expected
to be a [strftime](http://strftime.org/) pattern, such as `%Y-%m-%d`.

Require and invoke the function in your javascript code:

```js
require('browser-date-formatter')()
```

When the DOM is ready, this module finds all elements with a `data-date`
attribute and converts their text content to the given `data-format`. The
formatter function is executed every 5 seconds to keep relative dates fresh.

## Usage without browserify

If you're not using browserify in your project, you can use the
[unpkg.com](http://unpkg.com) hosted version instead:

```html
<script src="https://unpkg.com/browser-date-formatter/dist.js"></script>
<script>
  browserDateFormatter()
</script>
```

## Tests

```sh
npm install
npm test
```

## Dependencies

- [domready](https://ghub.io/domready): modern domready
- [strftime](https://ghub.io/prettydate): Format dates nicely
- [relative-date](https://ghub.io/relative-date): Javascript module for outputting relative dates.

## License

MIT

_Generated by [package-json-to-readme](https://github.com/zeke/package-json-to-readme)_
